@@ -1,4 +1,4 @@
-/*  
+/*
  * Copyright (c) Members of the EGEE Collaboration. 2004.
  * See http://www.eu-egee.org/partners/ for details on the copyright holders.
  *
@@ -18,10 +18,11 @@
 /** cgsi_plugin.h - Header file for the GSI gSOAP plugin
  *
  * @file cgsi_plugin.h
+ * @brief Header file for the GSI gSOAP plugin
  * @author Ben Couturier CERN, IT/ADC
  *
  * This is a GSI plugin for gSOAP. It uses the globus GSI libraries to implement
- * GSI secure authentification and encryption on top of gSOAP.
+ * GSI secure authentication and encryption on top of gSOAP.
  * The globus GSI bundle is necessary for the plugin to compile and run.
  *
  */
@@ -48,10 +49,10 @@ extern "C" {
 /** Disable comparing the server's host name with its certificate's CN. */
 #define CGSI_OPT_DISABLE_NAME_CHECK 0x10
 /** Keep alive the HTTP connection. */
-#define CGSI_OPT_KEEP_ALIVE         0x20  
+#define CGSI_OPT_KEEP_ALIVE         0x20
 /** Disable DN->userid mapping via gridmap-file. */
 #define CGSI_OPT_DISABLE_MAPPING    0x40
-/** Disable connect time VOMS parsing for better error handling 
+/** Disable connect time VOMS parsing for better error handling
  *  via an explicit call to retrieve_voms_creds() */
 #define CGSI_OPT_DISABLE_VOMS_CHECK 0x80
 /** Allow client and server to only connect together when
@@ -73,7 +74,7 @@ extern "C" {
 int soap_cgsi_init(struct soap *soap, int cgsi_options);
 
 /**
- * Generic contructor for the cgsi_plugin
+ * Generic constructor for the cgsi_plugin
  *
  * @param soap The soap structure for the request
  * @param plugin Pointer to the plugin data structure
@@ -84,7 +85,7 @@ int soap_cgsi_init(struct soap *soap, int cgsi_options);
 int cgsi_plugin(struct soap *soap, struct soap_plugin *plugin, void *arg);
 
 /**
- * Client contructor for the cgsi_plugin
+ * Client constructor for the cgsi_plugin
  *
  * @param soap The soap structure for the request
  * @param plugin Pointer to the plugin data structure
@@ -95,7 +96,7 @@ int cgsi_plugin(struct soap *soap, struct soap_plugin *plugin, void *arg);
 int client_cgsi_plugin(struct soap *soap, struct soap_plugin *plugin, void *arg);
 
 /**
- * Server contructor for the cgsi_plugin
+ * Server constructor for the cgsi_plugin
  *
  * @param soap The soap structure for the request
  * @param plugin Pointer to the plugin data structure
@@ -204,7 +205,7 @@ int retrieve_userca_and_voms_creds(struct soap *soap);
  *
  * @param soap The soap structure for the request
  *
- * @return The client CA is allocated in the soap structure (DON'T free), 
+ * @return The client CA is allocated in the soap structure (DON'T free),
  *         NULL otherwise
  */
 char *get_client_ca(struct soap *soap);
@@ -214,7 +215,7 @@ char *get_client_ca(struct soap *soap);
  *
  * @param soap The soap structure for the request
  *
- * @return The client voname is malloced in the soap structure (DON'T free), 
+ * @return The client voname is malloced in the soap structure (DON'T free),
  *         NULL otherwise
  */
 char *get_client_voname(struct soap *soap);
@@ -226,12 +227,67 @@ char *get_client_voname(struct soap *soap);
  *
  * @param nbfqans The number of returned Fully Qualified Attribute Names
  *
- * @return The client roles are malloced in the soap structure (DON'T free), 
+ * @return The client roles are malloced in the soap structure (DON'T free),
  *         NULL otherwise
  */
 char ** get_client_roles(struct soap *soap, int* nbfqans);
 
 
+/**
+ * Adjust CGSI-plugin's behaviour by setting one or more flags.  If a
+ * flag is not present in args then that flag is unaffected by this
+ * operation.  If a flag is currently set then attempting to set it
+ * will have no effect.
+ *
+ * @param soap The soap structure from gSOAP
+ *
+ * @param is_server 0 if client, 1 if server
+ *
+ * @param flags Bitwise OR of the flags to be set.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int cgsi_plugin_set_flags(struct soap *soap, int is_server, int flags);
+
+/**
+ * Adjust CGSI-plugin's behaviour by clearing one or more flags. If a
+ * flag is not present in args then it is unaffected by this
+ * operation.  If a flag is currently cleared then attempting to clear
+ * it will have no effect.
+ *
+ * @param soap The soap structure from gSOAP
+ *
+ * @param is_server 0 if client, 1 if server
+ *
+ * @param flags Bitwise OR of the flags to be cleared.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int cgsi_plugin_clr_flags(struct soap *soap, int is_server, int flags);
+
+/**
+ * Discover the current set of flags that are in effect.
+ *
+ * @param soap The soap structure from gSOAP
+ *
+ * @param is_server 0 if client, 1 if server
+ *
+ * @return the set of flags or -1 on error
+ */
+int cgsi_plugin_get_flags(struct soap *soap, int is_server);
+
+/**
+ * Set credentials without using environment variables
+ *
+ * @param soap The soap structure for the request
+ * @param is_server 0 if client, 1 if server
+ * @param x509_cert The certificate. If it is a proxy, you only need to specify this one
+ * @param x509_key  The key. Will be ignored if x509_cert is NULL!
+ *
+ * @return 0 on success, -1 on error.
+ */
+int cgsi_plugin_set_credentials(struct soap *soap, int is_server, const char* x509_cert, const char* x509_key);
+
 #ifdef __cplusplus
 }
 #endif
