@@ -21,13 +21,13 @@
  * @author Ben Couturier CERN, IT/ADC
  *
  * This is a GSI plugin for gSOAP. It uses the globus GSI libraries to implement
- * GSI secure authentification and encryption on top of gSOAP.
+ * GSI secure authentication and encryption on top of gSOAP.
  * The globus GSI bundle is necessary for the plugin to compile and run.
  *
  */
 
-#include <cgsi_plugin.h>
 #include <globus_gss_assist.h>
+#include <cgsi_plugin.h>
 #include <stdsoap2.h>
 
 #define CGSI_TRACE "CGSI_TRACE"
@@ -39,7 +39,8 @@
 
 #define CGSI_MAXNAMELEN 512
 
-struct cgsi_plugin_data {
+struct cgsi_plugin_data
+{
     int context_established;
     gss_cred_id_t credential_handle;
     gss_ctx_id_t  context_handle;
@@ -50,15 +51,19 @@ struct cgsi_plugin_data {
     int (*fclose)(struct soap*);
     char client_name[CGSI_MAXNAMELEN];
     char server_name[CGSI_MAXNAMELEN];
-    char username[CGSI_MAXNAMELEN];    
-    char user_ca[CGSI_MAXNAMELEN];    
+    char username[CGSI_MAXNAMELEN];
+    char user_ca[CGSI_MAXNAMELEN];
     int nb_iter;
-    int disable_hostname_check; 
+    int disable_hostname_check;
     int context_flags;
     int trace_mode;
     char trace_file[CGSI_MAXNAMELEN];
     gss_cred_id_t deleg_credential_handle;
     int deleg_cred_set;
+    gss_buffer_t buffered_in;
+    /* API-defined credentials */
+    char* x509_cert;
+    char* x509_key;
     /* Pointers to VOMS data */
     char *voname;
     char **fqan;
@@ -69,4 +74,5 @@ struct cgsi_plugin_data {
     int had_send_error;
     void *deleg_credential_token;
     size_t deleg_credential_token_len;
+    int start_new_line;
 };
